@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2014 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2016 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -338,7 +338,7 @@ sub _SignEncrypt {
                 KeyType   => "secret",
             });
             $res{exit_code} = 1;
-            return %res;
+            return (undef, %res);
         }
         $args{'Passphrase'} = $self->GetPassphrase( Address => $args{'Signer'} )
             unless defined $args{'Passphrase'};
@@ -947,6 +947,9 @@ sub GetCertificateInfo {
         $res{info}[0]{TrustLevel} = 0;
     }
 
+    $res{info}[0]{Formatted} = $res{info}[0]{User}[0]{String}
+        . " (issued by $res{info}[0]{Issuer}[0]{String})";
+
     return %res;
 }
 
